==> upload-api-client-internal-2.24.0.tgz: package/src/services/FilesV1Service.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { BeginUploadRequestV1 } from "../models/BeginUploadRequestV1";
import type { BeginUploadResponseV1 } from "../models/BeginUploadResponseV1";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { ContinuationToken } from "../models/ContinuationToken";
import type { DeleteFileBatchV1 } from "../models/DeleteFileBatchV1";
import type { FileApiV1PageSize } from "../models/FileApiV1PageSize";
import type { FileId } from "../models/FileId";
import type { FileSummaryExtended } from "../models/FileSummaryExtended";
import type { FileTagName } from "../models/FileTagName";
import type { FileTagPrefixSearch } from "../models/FileTagPrefixSearch";
import type { Paginated_FileSummaryExtended_ } from "../models/Paginated_FileSummaryExtended_";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import type { UploadPartV1 } from "../models/UploadPartV1";
import { request as __request } from "../core/request";

export class FilesV1Service {
  /**
   * Begins a new multipart file upload. Required API key type: 'secret_*' or 'public_*'.
   * @param requestBody File upload parameters.
   * @returns BeginUploadResponseV1 Success.
   * @throws ApiError
   */
  public static async beginMultipartUpload(requestBody: BeginUploadRequestV1): Promise<BeginUploadResponseV1> {
    const result = await __request({
      method: "POST",
      path: `/v1/files`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Deletes multiple files (asynchronously). Required API key type: 'secret_*' only.
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteFileBatch(requestBody: DeleteFileBatchV1): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/files`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Lists the files for a given account. Required API key type: 'secret_*' only.
   * @param accountId
   * @param pageSize
   * @param fileTag
   * @param fileTagPrefixSearch
   * @param backwardToken
   * @param forwardToken
   * @returns Paginated_FileSummaryExtended_ Success.
   * @throws ApiError
   */
  public static async getFiles(
    accountId: AccountId,
    pageSize: FileApiV1PageSize,
    fileTag?: FileTagName,
    fileTagPrefixSearch?: FileTagPrefixSearch,
    backwardToken?: ContinuationToken,
    forwardToken?: ContinuationToken
  ): Promise<Paginated_FileSummaryExtended_> {
    const result = await __request({
      method: "GET",
      path: `/v1/files`,
      query: {
        accountId: accountId,
        pageSize: pageSize,
        fileTag: fileTag,
        fileTagPrefixSearch: fileTagPrefixSearch,
        backwardToken: backwardToken,
        forwardToken: forwardToken
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Finalizes an upload part for an in-progress multipart upload. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @param uploadPartIndex
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async completeUploadPart(
    fileId: FileId,
    uploadPartIndex: UploadPartIndex,
    requestBody: CompleteUploadPartRequest
  ): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Gets a remaining upload part for an in-progress upload. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @param uploadPartIndex
   * @returns UploadPartV1 Success.
   * @throws ApiError
   */
  public static async getUploadPart(fileId: FileId, uploadPartIndex: UploadPartIndex): Promise<UploadPartV1> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Deletes a file (synchronously). Required API key type: 'secret_*' only.
   * @param fileId
   * @returns void
   * @throws ApiError
   */
  public static async deleteFile(fileId: FileId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/files/${fileId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Gets information about a specific file. Required API key type: 'secret_*' only.
   * @param fileId
   * @returns FileSummaryExtended Success.
   * @throws ApiError
   */
  public static async getFile(fileId: FileId): Promise<FileSummaryExtended> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @returns UploadPartList Success.
   * @throws ApiError
   */
  public static async getUploadParts(fileId: FileId): Promise<UploadPartList> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File not found.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-2.29.0.tgz: package/src/services/FilesV1Service.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { BeginMultipartUploadRequestV1 } from "../models/BeginMultipartUploadRequestV1";
import type { BeginMultipartUploadResponseV1 } from "../models/BeginMultipartUploadResponseV1";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { ContinuationToken } from "../models/ContinuationToken";
import type { DeleteFileBatchRequestV1 } from "../models/DeleteFileBatchRequestV1";
import type { FileApiV1PageSize } from "../models/FileApiV1PageSize";
import type { FileId } from "../models/FileId";
import type { FileSummaryExtended } from "../models/FileSummaryExtended";
import type { FileTagName } from "../models/FileTagName";
import type { FileTagPrefixSearch } from "../models/FileTagPrefixSearch";
import type { Paginated_FileSummaryExtended_ } from "../models/Paginated_FileSummaryExtended_";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import type { UploadPartV1 } from "../models/UploadPartV1";
import { request as __request } from "../core/request";

export class FilesV1Service {
  /**
   * Begins a new multipart file upload. Required API key type: 'secret_*' or 'public_*'.
   * @param requestBody File upload parameters.
   * @returns BeginMultipartUploadResponseV1 Success.
   * @throws ApiError
   */
  public static async beginMultipartUpload(
    requestBody: BeginMultipartUploadRequestV1
  ): Promise<BeginMultipartUploadResponseV1> {
    const result = await __request({
      method: "POST",
      path: `/v1/files`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Asynchronously deletes multiple files. Required API key type: 'secret_*' only.
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteFileBatch(requestBody: DeleteFileBatchRequestV1): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/files`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Lists the files for a given account. Required API key type: 'secret_*' only.
   * @param accountId
   * @param pageSize
   * @param fileTag
   * @param fileTagPrefixSearch
   * @param backwardToken
   * @param forwardToken
   * @returns Paginated_FileSummaryExtended_ Success.
   * @throws ApiError
   */
  public static async getFiles(
    accountId: AccountId,
    pageSize: FileApiV1PageSize,
    fileTag?: FileTagName,
    fileTagPrefixSearch?: FileTagPrefixSearch,
    backwardToken?: ContinuationToken,
    forwardToken?: ContinuationToken
  ): Promise<Paginated_FileSummaryExtended_> {
    const result = await __request({
      method: "GET",
      path: `/v1/files`,
      query: {
        accountId: accountId,
        pageSize: pageSize,
        fileTag: fileTag,
        fileTagPrefixSearch: fileTagPrefixSearch,
        backwardToken: backwardToken,
        forwardToken: forwardToken
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Finalizes an upload part for an in-progress multipart upload. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @param uploadPartIndex
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async completeUploadPart(
    fileId: FileId,
    uploadPartIndex: UploadPartIndex,
    requestBody: CompleteUploadPartRequest
  ): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Gets a remaining upload part for an in-progress upload. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @param uploadPartIndex
   * @returns UploadPartV1 Success.
   * @throws ApiError
   */
  public static async getUploadPart(fileId: FileId, uploadPartIndex: UploadPartIndex): Promise<UploadPartV1> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Synchronously deletes a file. Required API key type: 'secret_*' only.
   * @param fileId
   * @returns void
   * @throws ApiError
   */
  public static async deleteFile(fileId: FileId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/files/${fileId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Gets information about a specific file. Required API key type: 'secret_*' only.
   * @param fileId
   * @returns FileSummaryExtended Success.
   * @throws ApiError
   */
  public static async getFile(fileId: FileId): Promise<FileSummaryExtended> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @returns UploadPartList Success.
   * @throws ApiError
   */
  public static async getUploadParts(fileId: FileId): Promise<UploadPartList> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File not found.`
      }
    });
    return result.body;
  }
}
